// Include the PPM library
#include "ppm.h"

// PPM channel layout (update for your situation)
#define THROTTLE    3
#define RUDDER      4
#define PITCH       2
#define ROLL        1

// Variable to store the PPM values per channel
short throttle;
short rudder;
short pitch;
short roll;

// consider channel at 0 until at least this much is sensed
const int INPUT_DEADBAND = 25;             

// Loop interval time
const long interval = 10;
unsigned long previousMillis = 0;

void setup() {
  Serial.begin(115200);

  Serial.write("#254RESET\r");   
  delay(2000);  // wait 2 sec for reboot

  // Start the PPM function on PIN A3
  ppm.begin(A3, false);

  // Insoc servo setup
  Serial.println("#254EM1");  // EM0 = motion profile disabled
  Serial.println("#254SR10"); // Set the maximum speed in RPM
  Serial.println("#254LED7"); //0=Off; 1=Red; 2=Green; 3=Blue; 4=Yellow; 5=Cyan; 6=Magenta; 7=White
  
}

void loop() {
  // Interval at which the PPM & LSS Output are updated
  unsigned long currentMillis = millis();
  if (currentMillis - previousMillis >= interval) {
    PPMupdate();
    LSSupdate();
  }
}

// Updating all the PPM values to each channel Variable
void PPMupdate()
{ 
  throttle    =   constrain(map(ppm.read_midstick(THROTTLE, INPUT_DEADBAND), -500, 500, -900, 900), -900, 900);
  roll        =   constrain(map(ppm.read_midstick(ROLL, INPUT_DEADBAND), -500, 500, -900, 900), -900, 900);
  pitch       =   constrain(map(ppm.read_midstick(PITCH, INPUT_DEADBAND), -500, 500, -900, 900), -900, 900);
  rudder      =   constrain(map(ppm.read_midstick(RUDDER, INPUT_DEADBAND), -500, 500, -900, 900), -900, 900);
}

// Updating the positions of each LSS's
void LSSupdate()
{ 
  Serial.print("#1D");
  Serial.println(throttle);
  Serial.print("#2D");
  Serial.println(roll);
  Serial.print("#3D");
  Serial.println(pitch);
  Serial.print("#4D");
  Serial.println(rudder);
}
